Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(325)

Unified Diff: content/browser/tab_contents/tab_contents_delegate.h

Issue 8934011: Rename IntentsHost -> WebIntentsDispatcher and IntentsDispatcher -> WebIntentsHost. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/tab_contents/tab_contents_delegate.h
diff --git a/content/browser/tab_contents/tab_contents_delegate.h b/content/browser/tab_contents/tab_contents_delegate.h
index cc6801b2fb9322cd9839cda8586708d538211951..634c73bd932f3d0257a9d043165f4fe35e9165a3 100644
--- a/content/browser/tab_contents/tab_contents_delegate.h
+++ b/content/browser/tab_contents/tab_contents_delegate.h
@@ -32,7 +32,7 @@ class ListValue;
namespace content {
class BrowserContext;
struct FileChooserParams;
-class IntentsHost;
+class WebIntentsDispatcher;
class JavaScriptDialogCreator;
}
@@ -326,9 +326,11 @@ class CONTENT_EXPORT TabContentsDelegate {
const string16& title,
const string16& disposition);
- // Web Intents notification handler. Takes ownership of the |intents_host|.
- virtual void WebIntentDispatch(TabContents* tab,
- content::IntentsHost* intents_host);
+ // Web Intents notification handler. Takes ownership of the
+ // |intents_dispatcher|.
+ virtual void WebIntentDispatch(
+ TabContents* tab,
+ content::WebIntentsDispatcher* intents_dispatcher);
// Result of string search in the page. This includes the number of matches
// found and the selection rect (in screen coordinates) for the string found.

Powered by Google App Engine
This is Rietveld 408576698